/**
  ******************************************************************************
  * @file Hyperterminal\main.c
  * @brief This file contains the main function for interface Hyperterminal with STM8S UART2.
  * @author STMicroelectronics - MCD Application Team
  * @version V1.0.0
  * @date 15/10/2009
  ******************************************************************************
  *
  */

// Includes ------------------------------------------------------------------
#include "stm8s.h"
#include "hyperterminal.h"

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------
// Private functions ---------------------------------------------------------
u32 LSIMeasurment(void); // function used for beeper calibration 

/**
  * @brief Validation firmware main entry point.
  * @par Parameters:
  * None
  * @retval 
  * None
  */
void main(void)
{
	  TIM3_DeInit();
    // Time base configuration  
		TIM3_TimeBaseInit(TIM3_PRESCALER_1,0xFFFF);
		TIM3_ITConfig(TIM3_IT_UPDATE, ENABLE);

    // Enable general interrupts 
    enableInterrupts();

	  // Set GPIO for LED LD1 (PD0)  
		GPIO_Init(GPIOD, 0x01 , GPIO_MODE_OUT_PP_LOW_FAST);
		
    // High speed internal clock prescaler: 1
    CLK_HSIPrescalerConfig(CLK_PRESCALER_HSIDIV1);

		/* UART2 configuration 
		------------------------------------------------------*/
    /* UART2 configured as follow:
      		- BaudRate = 9600 baud  
          - Word Length = 8 Bits
          - One Stop Bit
          - Odd parity
          - Receive and transmit enabled
          - UART2 Clock disabled
    */
		UART2_DeInit();
    UART2_Init((u32)9600, UART2_WORDLENGTH_8D, UART2_STOPBITS_1, UART2_PARITY_ODD, UART2_SYNCMODE_CLOCK_DISABLE, UART2_MODE_TXRX_ENABLE);
		
		 // BEEP calibration 
    BEEP_LSICalibrationConfig(LSIMeasurment());		
		
		// Main loop
    while (1){
			Main_Menu();
	}
}


u32 LSIMeasurment(void)
{

  u32 lsi_freq_hz = 0x0;
  u32 fmaster = 0x0;
  u16 ICValue1 = 0x0;
  u16 ICValue2 = 0x0;

  // Get master frequency 
  fmaster = CLK_GetClockFreq();

  // Enable the LSI measurement: LSI clock connected to timer Input Capture 1 
  AWU->CSR |= AWU_CSR_MSR;

#if defined (STM8S903) || defined (STM8S103)
  // Measure the LSI frequency with TIMER Input Capture 1 
  
  // Capture only every 8 events!!! 
  // Enable capture of TI1 
	TIM1_ICInit(TIM1_CHANNEL_1, TIM1_ICPOLARITY_RISING, TIM1_ICSELECTION_DIRECTTI, TIM1_ICPSC_DIV8, 0);
	
  // Enable TIM1 
  TIM1_Cmd(ENABLE);
  
  // wait a capture on cc1 
  while((TIM1->SR1 & TIM1_FLAG_CC1) != TIM1_FLAG_CC1);
  // Get CCR1 value
  ICValue1 = TIM1_GetCapture1();
  TIM1_ClearFlag(TIM1_FLAG_CC1);
  
  // wait a capture on cc1 
  while((TIM1->SR1 & TIM1_FLAG_CC1) != TIM1_FLAG_CC1);
  // Get CCR1 value
  ICValue2 = TIM1_GetCapture1();
  TIM1_ClearFlag(TIM1_FLAG_CC1);
  
  // Disable IC1 input capture 
  TIM1->CCER1 &= (u8)(~TIM1_CCER1_CC1E);
  // Disable timer2 
  TIM1_Cmd(DISABLE);
  
#else  
  // Measure the LSI frequency with TIMER Input Capture 1 
  
  // Capture only every 8 events!!! 
  // Enable capture of TI1 
  TIM3_ICInit(TIM3_CHANNEL_1, TIM3_ICPOLARITY_RISING, TIM3_ICSELECTION_DIRECTTI, TIM3_ICPSC_DIV8, 0);

  // Enable TIM3 
  TIM3_Cmd(ENABLE);

	// wait a capture on cc1 
  while ((TIM3->SR1 & TIM3_FLAG_CC1) != TIM3_FLAG_CC1);
	// Get CCR1 value
  ICValue1 = TIM3_GetCapture1();
  TIM3_ClearFlag(TIM3_FLAG_CC1);

  // wait a capture on cc1 
  while ((TIM3->SR1 & TIM3_FLAG_CC1) != TIM3_FLAG_CC1);
    // Get CCR1 value
  ICValue2 = TIM3_GetCapture1();
	TIM3_ClearFlag(TIM3_FLAG_CC1);

  // Disable IC1 input capture 
  TIM3->CCER1 &= (u8)(~TIM3_CCER1_CC1E);
  // Disable timer3 
  TIM3_Cmd(DISABLE);
#endif

  // Compute LSI clock frequency 
  lsi_freq_hz = (8 * fmaster) / (ICValue2 - ICValue1);
  
  // Disable the LSI measurement: LSI clock disconnected from timer Input Capture 1 
  AWU->CSR &= (u8)(~AWU_CSR_MSR);

 return (lsi_freq_hz);
}


